==> nextcloud-18.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/es.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "La operación dada no es valida",
    "The given regular expression is invalid" : "La expresión regular dada no es valida",
    "The given file size is invalid" : "El tamaño del archivo dado no es válido ",
    "The given tag id is invalid" : "El id de etiqueta dado no es valido",
    "The given IP range is invalid" : "El rango de IPs no es valido",
    "The given IP range is not valid for IPv4" : "El rango de IP no es valida para IPv4",
    "The given IP range is not valid for IPv6" : "El rango de IP no es valida para IPv6",
    "The given time span is invalid" : "El intervalo temporal dado es inválido",
    "The given start time is invalid" : "La hora de inicio dada no es válida",
    "The given end time is invalid" : "El tiempo final no es valido",
    "The given group does not exist" : "El grupo dado no existe",
    "File" : "Archivo",
    "File created" : "Archivo creado",
    "File updated" : "Archivo actualizado",
    "File renamed" : "Archivo renombrado",
    "File deleted" : "Archivo eliminado",
    "File accessed" : "Archivo accedido",
    "File copied" : "Archivo copiado",
    "Tag assigned" : "Etiqueta asignada",
    "Someone" : "Alguien",
    "%s created %s" : "%s ha creado %s",
    "%s modified %s" : "%s ha modificado %s",
    "%s deleted %s" : "%s ha eliminado %s",
    "%s accessed %s" : "%s ha accedido a %s",
    "%s renamed %s" : "%s ha renombrado %s",
    "%s copied %s" : "%s ha copiado %s",
    "%s assigned %s to %s" : "%s ha asignado %s a %s",
    "Operation #%s does not exist" : "Operación #%s no existe",
    "Entity %s does not exist" : "Entidad %s no existe",
    "Entity %s is invalid" : "La entidad %s no es valida",
    "No events are chosen." : "No se ha elegido ningún evento.",
    "Entity %s has no event %s" : "La entidad %s no tiene eventos %s",
    "Operation %s does not exist" : "Operación %s no existe",
    "Operation %s is invalid" : "Operación %s no es valida",
    "At least one check needs to be provided" : "Has de seleccionar al menos una comprobación",
    "Invalid check provided" : "La comprobación proporcionada no es válida",
    "Check %s does not exist" : "La comprobación %s no existe",
    "Check %s is invalid" : "La comprobación %s no es válida",
    "Check %s is not allowed with this entity" : "La comprobación %s no se permite con esta entidad",
    "Check #%s does not exist" : "El chequeo #%s no existe",
    "Check %s is invalid or does not exist" : "Comprueba %s no es valido o no existe",
    "Flow" : "Flujo",
    "Nextcloud workflow engine" : "Motor de flujo de trabajo de Nextcloud",
    "Select a filter" : "Seleccione un filtro",
    "Select a comparator" : "Seleccione un comparador",
    "Select a file type" : "Selecciona un tipo de archivo",
    "e.g. httpd/unix-directory" : "p.ej.. httpd/carpeta-unix",
    "Images" : "Imágenes",
    "Office documents" : "Documentos de oficina",
    "PDF documents" : "Documentos PDF",
    "Custom mimetype" : "Tipo MIME (mimetype) personalizado",
    "Select a tag" : "Selecciona una etiqueta",
    "No results" : "Sin resultados",
    "%s (invisible)" : "%s (invisible)",
    "%s (restricted)" : "%s (restringido)",
    "Please enter a valid time span" : "Por favor especifique un intervalo de tiempo válido",
    "Select a request URL" : "Selecciona una URL de petición",
    "Predefined URLs" : "URLs predefinidas",
    "Files WebDAV" : "Archivos WebDAV",
    "Others" : "Otros",
    "Custom URL" : "URL personalizada",
    "Select a user agent" : "Selecciona un agente de usuario",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de escritorio",
    "Thunderbird & Outlook addons" : "Complementos de Thunderbird y Outlook",
    "Custom user agent" : "Agente de usuario personalizado",
    "At least one event must be selected" : "Has de seleccionar al menos un evento",
    "Add new flow" : "Añadir nuevo flujo",
    "When" : "Cuando",
    "and" : "y",
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "The configuration is invalid" : "La configuración es incorrecta",
    "Active" : "Activo",
    "Save" : "Guardar",
    "Available flows" : "Flujos disponibles",
    "For details on how to write your own flow, check out the development documentation." : "Para detalles acerca de cómo escribir su propio flujo, mire la documentación dedesarrollo.",
    "More flows" : "Más flujos",
    "Browse the app store" : "Explora la tienda de aplicaciones",
    "Show less" : "Ver menos",
    "Show more" : "Ver más",
    "Configured flows" : "Configurar flujos",
    "Your flows" : "Sus flujos",
    "matches" : "coincidencias",
    "does not match" : "no coincide",
    "is" : "es/esta",
    "is not" : "no es/esta",
    "File name" : "Nombre del archivo",
    "File MIME type" : "Tipo MIME del archivo",
    "File size (upload)" : "Tamaño del archivo (para subir)",
    "less" : "menos",
    "less or equals" : "menor o igual",
    "greater or equals" : "mayor o igual",
    "greater" : "mayor",
    "Request remote address" : "Solicitar dirección remota",
    "matches IPv4" : "IPv4 coincidencias",
    "does not match IPv4" : "IPv4 sin coincidencias",
    "matches IPv6" : "IPv6 coincidencias",
    "does not match IPv6" : "IPv6 sin coincidencias",
    "File system tag" : "Etiqueta de archivo de sistema",
    "is tagged with" : "esta etiquetado con",
    "is not tagged with" : "no esta etiquetado con",
    "Request URL" : "URL de solicitud",
    "Request time" : "Tiempo de espera",
    "between" : "entre",
    "not between" : "no entre",
    "Request user agent" : "Solicitud del agente usuario ",
    "User group membership" : "Pertenencia a un grupo de usuarios",
    "is member of" : "es miembro de",
    "is not member of" : "no es miembro de",
    "Short rule description" : "Descripción de la regla corta",
    "Add rule" : "Añadir regla",
    "Reset" : "Restablecer",
    "Saving…" : "Guardando...",
    "Group list is empty" : "La lista de grupos está vacía",
    "Unable to retrieve the group list" : "No es posible recibir la lista de grupos",
    "Saved" : "Guardado",
    "Saving failed:" : "Fallo al guardar:",
    "Add rule group" : "Añadir regla al grupo",
    "Example: {placeholder}" : "Ejemplo: {placeholder}",
    "Select tag…" : "Seleccionar etiqueta...",
    "Start" : "Inicio",
    "End" : "Final",
    "Select timezone…" : "Seleccionar zona horaria...",
    "Sync clients" : "Clientes de sincronización",
    "Tag management" : "Tratamiento de etiquetas",
    "Files workflow engine" : "Motor de flujo de trabajo de archivos",
    "Open documentation" : "Documentación abierta",
    "Loading…" : "Cargando..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/es.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "La operación dada no es valida",
    "The given regular expression is invalid" : "La expresión regular dada no es valida",
    "The given file size is invalid" : "El tamaño del archivo dado no es válido ",
    "The given tag id is invalid" : "El id de etiqueta dado no es valido",
    "The given IP range is invalid" : "El rango de IPs no es valido",
    "The given IP range is not valid for IPv4" : "El rango de IP no es valida para IPv4",
    "The given IP range is not valid for IPv6" : "El rango de IP no es valida para IPv6",
    "The given time span is invalid" : "El intervalo temporal dado es inválido",
    "The given start time is invalid" : "La hora de inicio dada no es válida",
    "The given end time is invalid" : "El tiempo final no es valido",
    "The given group does not exist" : "El grupo dado no existe",
    "File" : "Archivo",
    "File created" : "Archivo creado",
    "File updated" : "Archivo actualizado",
    "File renamed" : "Archivo renombrado",
    "File deleted" : "Archivo eliminado",
    "File accessed" : "Archivo accedido",
    "File copied" : "Archivo copiado",
    "Tag assigned" : "Etiqueta asignada",
    "Someone" : "Alguien",
    "%s created %s" : "%s ha creado %s",
    "%s modified %s" : "%s ha modificado %s",
    "%s deleted %s" : "%s ha eliminado %s",
    "%s accessed %s" : "%s ha accedido a %s",
    "%s renamed %s" : "%s ha renombrado %s",
    "%s copied %s" : "%s ha copiado %s",
    "%s assigned %s to %s" : "%s ha asignado %s a %s",
    "Operation #%s does not exist" : "Operación #%s no existe",
    "Entity %s does not exist" : "Entidad %s no existe",
    "Entity %s is invalid" : "La entidad %s no es valida",
    "No events are chosen." : "No se ha elegido ningún evento.",
    "Entity %s has no event %s" : "La entidad %s no tiene eventos %s",
    "Operation %s does not exist" : "Operación %s no existe",
    "Operation %s is invalid" : "Operación %s no es valida",
    "At least one check needs to be provided" : "Has de seleccionar al menos una comprobación",
    "Invalid check provided" : "La comprobación proporcionada no es válida",
    "Check %s does not exist" : "La comprobación %s no existe",
    "Check %s is invalid" : "La comprobación %s no es válida",
    "Check %s is not allowed with this entity" : "La comprobación %s no se permite con esta entidad",
    "Check #%s does not exist" : "El chequeo #%s no existe",
    "Check %s is invalid or does not exist" : "Comprueba %s no es valido o no existe",
    "Flow" : "Flujo",
    "Nextcloud workflow engine" : "Motor de flujo de trabajo de Nextcloud",
    "Select a filter" : "Seleccione un filtro",
    "Select a comparator" : "Seleccione un comparador",
    "Select a file type" : "Selecciona un tipo de archivo",
    "e.g. httpd/unix-directory" : "p.ej.: httpd/carpeta-unix",
    "Folder" : "Carpeta",
    "Images" : "Imágenes",
    "Office documents" : "Documentos de oficina",
    "PDF documents" : "Documentos PDF",
    "Custom mimetype" : "Tipo MIME (mimetype) personalizado",
    "Select a tag" : "Selecciona una etiqueta",
    "No results" : "Sin resultados",
    "%s (invisible)" : "%s (invisible)",
    "%s (restricted)" : "%s (restringido)",
    "Please enter a valid time span" : "Por favor especifique un intervalo de tiempo válido",
    "Select a request URL" : "Selecciona una URL de petición",
    "Predefined URLs" : "URLs predefinidas",
    "Files WebDAV" : "Archivos WebDAV",
    "Others" : "Otros",
    "Custom URL" : "URL personalizada",
    "Select a user agent" : "Selecciona un agente de usuario",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de escritorio",
    "Thunderbird & Outlook addons" : "Complementos de Thunderbird y Outlook",
    "Custom user agent" : "Agente de usuario personalizado",
    "At least one event must be selected" : "Has de seleccionar al menos un evento",
    "Add new flow" : "Añadir nuevo flujo",
    "When" : "Cuando",
    "and" : "y",
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "The configuration is invalid" : "La configuración es incorrecta",
    "Active" : "Activo",
    "Save" : "Guardar",
    "Available flows" : "Flujos disponibles",
    "For details on how to write your own flow, check out the development documentation." : "Para detalles acerca de cómo escribir su propio flujo, mire la documentación dedesarrollo.",
    "More flows" : "Más flujos",
    "Browse the app store" : "Explora la tienda de aplicaciones",
    "Show less" : "Ver menos",
    "Show more" : "Ver más",
    "Configured flows" : "Configurar flujos",
    "Your flows" : "Sus flujos",
    "matches" : "coincidencias",
    "does not match" : "no coincide",
    "is" : "es/esta",
    "is not" : "no es/esta",
    "File name" : "Nombre del archivo",
    "File MIME type" : "Tipo MIME del archivo",
    "File size (upload)" : "Tamaño del archivo (para subir)",
    "less" : "menos",
    "less or equals" : "menor o igual",
    "greater or equals" : "mayor o igual",
    "greater" : "mayor",
    "Request remote address" : "Solicitar dirección remota",
    "matches IPv4" : "IPv4 coincidencias",
    "does not match IPv4" : "IPv4 sin coincidencias",
    "matches IPv6" : "IPv6 coincidencias",
    "does not match IPv6" : "IPv6 sin coincidencias",
    "File system tag" : "Etiqueta de archivo de sistema",
    "is tagged with" : "esta etiquetado con",
    "is not tagged with" : "no esta etiquetado con",
    "Request URL" : "URL de solicitud",
    "Request time" : "Tiempo de espera",
    "between" : "entre",
    "not between" : "no entre",
    "Request user agent" : "Solicitud del agente usuario ",
    "User group membership" : "Pertenencia a un grupo de usuarios",
    "is member of" : "es miembro de",
    "is not member of" : "no es miembro de"
},
"nplurals=2; plural=(n != 1);");
